
|pypi| |actions| |codecov| |downloads|

edc-vitals
----------

Classes for BP, weight, heart rate, respiratory rate, temperature etc


Settings:
+++++++++

::

    # Blood pressure/severe hypertension
    EDC_VITALS_SYS_UPPER: (default=180)
    EDC_VITALS_DIA_UPPER: (default=110)

    # Temperature/fever
    EDC_VITALS_G3_FEVER_LOWER: (default=39.3)
    EDC_VITALS_G4_FEVER_LOWER: (default=40.0)

.. |pypi| image:: https://img.shields.io/pypi/v/edc-vitals.svg
    :target: https://pypi.python.org/pypi/edc-vitals

.. |actions| image:: https://github.com/clinicedc/edc-vitals/actions/workflows/build.yml/badge.svg
  :target: https://github.com/clinicedc/edc-vitals/actions/workflows/build.yml

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-vitals/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/clinicedc/edc-vitals

.. |downloads| image:: https://pepy.tech/badge/edc-vitals
   :target: https://pepy.tech/project/edc-vitals
